package cn.com.infosec.asn1.x509;

import cn.com.infosec.asn1.ASN1Encodable;
import cn.com.infosec.asn1.ASN1EncodableVector;
import cn.com.infosec.asn1.ASN1Sequence;
import cn.com.infosec.asn1.ASN1TaggedObject;
import cn.com.infosec.asn1.DERInteger;
import cn.com.infosec.asn1.DERObject;
import cn.com.infosec.asn1.DERSequence;
import cn.com.infosec.asn1.DERTaggedObject;
import java.math.BigInteger;

public class GeneralSubtree extends ASN1Encodable {
   private static final BigInteger ZERO = BigInteger.valueOf(0L);
   private GeneralName base;
   private DERInteger minimum;
   private DERInteger maximum;

   public GeneralSubtree(ASN1Sequence seq) {
      this.base = GeneralName.getInstance(seq.getObjectAt(0));
      int var2;
      if ((var2 = seq.size()) != 1) {
         if (var2 != 2) {
            if (var2 != 3) {
               throw new IllegalArgumentException("Bad sequence size: " + seq.size());
            }

            this.minimum = DERInteger.getInstance(ASN1TaggedObject.getInstance(seq.getObjectAt(1)));
            this.maximum = DERInteger.getInstance(ASN1TaggedObject.getInstance(seq.getObjectAt(2)));
         } else {
            ASN1TaggedObject seq1;
            if ((var2 = (seq1 = ASN1TaggedObject.getInstance(seq.getObjectAt(1))).getTagNo()) != 0) {
               if (var2 != 1) {
                  throw new IllegalArgumentException("Bad tag number: " + seq1.getTagNo());
               }

               this.maximum = DERInteger.getInstance(seq1, false);
            } else {
               this.minimum = DERInteger.getInstance(seq1, false);
            }
         }
      }

   }

   public GeneralSubtree(GeneralName base, BigInteger minimum, BigInteger maximum) {
      this.base = base;
      if (maximum != null) {
         DERInteger base1;
         base1 = new DERInteger.<init>(maximum);
         this.maximum = base1;
      }

      if (minimum == null) {
         this.minimum = null;
      } else {
         GeneralSubtree var10000 = this;
         DERInteger var4;
         var4 = new DERInteger.<init>(minimum);
         var10000.minimum = var4;
      }

   }

   public GeneralSubtree(GeneralName base) {
      this(base, (BigInteger)null, (BigInteger)null);
   }

   public static GeneralSubtree getInstance(ASN1TaggedObject o, boolean explicit) {
      return new GeneralSubtree(ASN1Sequence.getInstance(o, explicit));
   }

   public static GeneralSubtree getInstance(Object obj) {
      if (obj == null) {
         return null;
      } else {
         return obj instanceof GeneralSubtree ? (GeneralSubtree)obj : new GeneralSubtree(ASN1Sequence.getInstance(obj));
      }
   }

   public GeneralName getBase() {
      return this.base;
   }

   public BigInteger getMinimum() {
      DERInteger var1;
      return (var1 = this.minimum) == null ? ZERO : var1.getValue();
   }

   public BigInteger getMaximum() {
      DERInteger var1;
      return (var1 = this.maximum) == null ? null : var1.getValue();
   }

   public DERObject toASN1Object() {
      ASN1EncodableVector var1;
      ASN1EncodableVector var10001 = var1 = new ASN1EncodableVector;
      var1.<init>();
      var10001.add(this.base);
      DERInteger var2;
      DERTaggedObject var5;
      if ((var2 = this.minimum) != null && !var2.getValue().equals(ZERO)) {
         DERTaggedObject var6 = var5 = new DERTaggedObject;
         DERInteger var3 = this.minimum;
         var6.<init>(false, 0, var3);
         var1.add(var5);
      }

      DERInteger var4;
      if ((var4 = this.maximum) != null) {
         var5 = new DERTaggedObject.<init>(false, 1, var4);
         var1.add(var5);
      }

      return new DERSequence(var1);
   }
}
